IAM Contrib Admin — Django Identity and Access Management documentation

# IAM Contrib Admin

Table of Contents

- Admin Blocks

- Mixins

## Admin Blocks

class iam.contrib.admin.blocks.BaseHasAuthorAdminMixin

class iam.contrib.admin.blocks.BaseHasOwnerAdminMixin

class iam.contrib.admin.blocks.HasAuthorAdminBlock

  Admin block for models with an author linked to a profile

class iam.contrib.admin.blocks.HasAuthorAdminMixin

class iam.contrib.admin.blocks.HasOwnerAdminBlock

  Admin block for models with an owner linked to a profile

class iam.contrib.admin.blocks.HasOwnerAdminMixin

## Mixins

class iam.contrib.admin.mixins.AutoOwnerAdminMixin

  Admin mixin that autofills an owner field (denoted by owner_field, default `owner`) with the appropriate profile of the user who is logged in.

class iam.contrib.admin.mixins.FieldsetPermissionsMixin

  Allow attaching permissions certain fieldsets, so we can hide them for users without access.